<?php

require_once('includes/config.php');

if(!defined('_PS_VERSION_'))
    exit;

require_once(_PS_MODULE_DIR_ . 'smspubli/controller/HookActionController.php');



class SmsPubli extends Module
{
    public static $instance;

    public $context;
    public $country;
    public $module_company_name;
    
    public function __construct()
    {
        $this->name = 'smspubli';
        $this->tab = 'other';
        $this->version = '1.4';
        $this->author = 'SMSpubli';
        $this->need_instance = 0;
        $this->is_configurable = 0;

        parent::__construct();

        $this->displayName = $this->l('SMSpubli');
        $this->description = $this->l('Module for sending SMS');

        $language_iso = Language::getIsoById((new Cookie('psAdmin'))->id_lang);
        $this->context->smarty->assign('language_iso', $language_iso);
        $this->country = new Country();
        $this->module_company_name = "SMS sending module";        
    }

    public static function getInstance()
    {
        if (!isset(self::$instance)) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    public function install()
    {
        if (Shop::isFeatureActive())
            Shop::setContext(Shop::CONTEXT_ALL);

        if ( parent::install() == false ) {
            return false;
        }

        Db::getInstance()->Execute("CREATE TABLE IF NOT EXISTS " . _DB_PREFIX_ . "smspubli_sms_pending (
            `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
            `id_user` int(10) unsigned DEFAULT NULL,
            `sender` varchar(15) NOT NULL,
            `calling_code` varchar(4) NOT NULL,
            `recipient` varchar(15) NOT NULL,
            `text` varchar(500) NOT NULL,
            `datetime_to_send` datetime NOT NULL,
            `ttl` mediumint(8) unsigned NOT NULL DEFAULT '604800' COMMENT 'Seconds for the SMS expires',
            `encoding` enum('7bit','8bit') NOT NULL DEFAULT '7bit',
            `iso_alpha2` char(2) DEFAULT NULL,
            `custom` varchar(32) NOT NULL DEFAULT '',
            `reserved` int(10) unsigned NOT NULL DEFAULT '0',
            `reserved_until` datetime NULL DEFAULT NULL,
            `row_created` datetime NULL DEFAULT NULL,
            `row_updated` timestamp NULL DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            KEY `datetime_to_send` (`datetime_to_send`),
            KEY `id_clinic` (`id_user`)
            ) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=utf8;");

        Db::getInstance()->Execute("CREATE TABLE IF NOT EXISTS " . _DB_PREFIX_ . "smspubli_sms_sent (
            `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
            `id_user` int(10) NOT NULL DEFAULT '0',
            `id_sms` varchar(32) DEFAULT NULL,
            `sender` varchar(15) NOT NULL DEFAULT '',
            `calling_code` varchar(4) NOT NULL DEFAULT '',
            `recipient` varchar(15) NOT NULL DEFAULT '',
            `text` varchar(500) NOT NULL DEFAULT '',
            `custom` varchar(32) NOT NULL DEFAULT '',
            `num_sms` tinyint(1) unsigned NOT NULL DEFAULT '1',
            `api_response` enum('','OK','INVALID_CONTENT_TYPE','JSON_PARSE_ERROR','MISSING_PARAMS','BAD_PARAMS','UNAUTHORIZED','INVALID_SENDER','INVALID_DESTINATION','INVALID_TEXT','INVALID_DATETIME','NOT_ENOUGH_BALANCE','LIMIT_EXCEEDED') NOT NULL DEFAULT '',
            `http_status_code` smallint(4) unsigned NOT NULL DEFAULT '200',
            `dlr_status` enum('PENDING','UNKNOWN','DELIVRD','UNDELIV','EXPIRED','REJECTD') NOT NULL DEFAULT 'PENDING',
            `row_created` datetime NULL DEFAULT NULL,
            `row_updated` timestamp NULL DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            KEY `id_sms` (`id_sms`),
            KEY `api_response` (`api_response`),
            KEY `dlr_status` (`dlr_status`),
            KEY `id_user` (`id_user`),
            KEY `custom` (`custom`)
            ) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8;");

        Db::getInstance()->Execute("CREATE TABLE IF NOT EXISTS " . _DB_PREFIX_ . "smspubli_sms_dlr (
            `id_sms` char(32) NOT NULL DEFAULT '',
            `dlr_status` enum('PENDING','UNKNOWN','DELIVRD','UNDELIV','EXPIRED','REJECTD') NOT NULL DEFAULT 'PENDING',
            `row_created` datetime NULL DEFAULT NULL,
            `row_updated` timestamp NULL DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id_sms`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;");

        Db::getInstance()->Execute("CREATE TABLE IF NOT EXISTS " . _DB_PREFIX_ . "smspubli_prefix (
            `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
            `iso_alpha2` CHAR(2) NOT NULL,
            `calling_code` VARCHAR(5) NOT NULL DEFAULT '',
            `mcc` VARCHAR(5) NULL DEFAULT NULL,
            `name_es` VARCHAR(200) NULL DEFAULT NULL,
            `name_en` VARCHAR(200) NULL DEFAULT NULL,
            `name_it` VARCHAR(200) NULL DEFAULT NULL,
            `name_de` VARCHAR(200) NULL DEFAULT NULL,
            `name_fr` VARCHAR(200) NULL DEFAULT NULL,
            `name_pt` VARCHAR(200) NULL DEFAULT NULL,
            PRIMARY KEY (`id`)
            ) ENGINE=InnoDB  DEFAULT CHARSET=utf8;");


        if (! Db::getInstance()->ExecuteS("SELECT * FROM ". _DB_PREFIX_ . "smspubli_prefix")) {
            $this->insertPrefixes();
        }

        Db::getInstance()->Execute("CREATE TABLE IF NOT EXISTS " . _DB_PREFIX_ . "smspubli_module_config (
            `id` INT(3) NOT NULL AUTO_INCREMENT,
            `api_key` VARCHAR(100) NULL DEFAULT NULL,
            `from` VARCHAR(11) NOT NULL,
            `frequency_advert_out_stock` VARCHAR(100) NOT NULL,
            `min_qty_advert_out_stock` INT(3) NOT NULL,
            `send_at` TIME NULL DEFAULT NULL,
            PRIMARY KEY (`id`)
            ) ENGINE=InnoDB  DEFAULT CHARSET=utf8;");

        if (! Db::getInstance()->ExecuteS("SELECT * FROM ". _DB_PREFIX_ . "smspubli_module_config")) {
            $shop_name = Configuration::get('PS_SHOP_NAME');
            $sender = (strlen($shop_name) > 11) ? substr($shop_name, 0, 11) : $shop_name;

            $query = "INSERT INTO " . _DB_PREFIX_ . "smspubli_module_config
                (`from`, `frequency_advert_out_stock`, `min_qty_advert_out_stock`) VALUES
                ('" . $sender . "', '24', 10)";

            Db::getInstance()->Execute($query);
        }

        Db::getInstance()->Execute("CREATE TABLE IF NOT EXISTS " . _DB_PREFIX_ . "smspubli_admins (
            `id` INT(3) NOT NULL AUTO_INCREMENT,
            `name` VARCHAR(100) NOT NULL,
            `prefix` VARCHAR(5) NOT NULL DEFAULT '',
            `mobile_phone` VARCHAR(50) NOT NULL,
            PRIMARY KEY (`id`)
            ) ENGINE=InnoDB  DEFAULT CHARSET=utf8;");


        Db::getInstance()->Execute("CREATE TABLE IF NOT EXISTS " . _DB_PREFIX_ . "smspubli_customer_sms_config (
            `id` INT(3) NOT NULL AUTO_INCREMENT,
            `hook` VARCHAR(100) CHARACTER SET utf8 NOT NULL,
            `option_id` TINYINT(1),
            `message` LONGTEXT CHARACTER SET utf8 NOT NULL,
            `active` TINYINT(1)  NOT NULL DEFAULT 0,
            PRIMARY KEY (`id`)
            ) ENGINE=InnoDB  DEFAULT CHARSET=utf8;");

        if (! Db::getInstance()->ExecuteS("SELECT * FROM ". _DB_PREFIX_ . "smspubli_customer_sms_config")) {
            Db::getInstance()->Execute("INSERT INTO " . _DB_PREFIX_ . "smspubli_customer_sms_config
                (`id`, `hook`, `option_id`, `message`, `active`) VALUES
                (2, 'actionOrderStatusPostUpdate', 2, 'Estimado {customer_firstname}, el estado de su pedido {order_id} ha cambiado a pago aceptado.', 0),
                (3, 'actionOrderStatusPostUpdate', 3, 'Estimado {customer_firstname}, su pedido {order_id} está en preoceso de preparación. ', 0),
                (4, 'actionOrderStatusPostUpdate', 4, 'Estimado {customer_firstname}, su pedido {order_id} ha sido enviado.', 0),
                (5, 'actionOrderStatusPostUpdate', 5, 'Estimado {customer_firstname}, su pedido {order_id} ha sido entregado.', 0),
                (6, 'actionOrderStatusPostUpdate', 6, 'Estimado {customer_firstname}, el estado de su pedido {order_id} ha cambiado a cancelado.', 0),
                (7, 'actionOrderStatusPostUpdate', 7, 'Estimado {customer_firstname}, el estado de su pedido {order_id} ha cambiado a reembolso.', 0),
                (8, 'actionOrderStatusPostUpdate', 8, 'Estimado {customer_firstname}, el estado de su pedido {order_id} ha cambiado a error en el pago.', 0),
                (9, 'actionOrderStatusPostUpdate', 9, 'Estimado {customer_firstname}, el estado de su pedido {order_id} ha cambiado a cambiado a productos fuera de línea.', 0),
                (12, 'actionOrderStatusPostUpdate', 12, 'Estimado {customer_firstname}, el estado de su pedido {order_id} ha cambiado a pago a distancia aceptado.', 0),
                (13, 'actionValidateOrder', 0, 'Su pedido {order_id} ha sido creado con éxito. Modo de pago: {order_payment}. Importe: {order_total_paid}{order_currency}', 0),
                (14, 'actionPaymentConfirmation', 0, 'El pago por su pedido {order_id} ha sido recibido correctamente.', 0),
                (15, 'actionOrderReturn', 0, 'Hemos recibido su solicitud de devolución del pedido {order_id}.', 0),
                (16, 'actionCustomerAccountAdd', 0, 'Bienvenid@ a {shop_name}. Su cuenta se ha creado correctamente.', 0)");


                //(1, 'actionOrderStatusPostUpdate', 1, 'Estimado {customer_firstname}, el estado de su pedido {order_id} es pendiente de pago por cheque', 0),
                //(10, 'actionOrderStatusPostUpdate', 10, 'Estimado {customer_firstname}, el estado de su pedido {order_id} es pendiente de pago por transferencia bancaria.', 0),
                //(11, 'actionOrderStatusPostUpdate', 11, 'Estimado {customer_firstname}, el setado de su pedido {order_id} es pendiente de pago por PayPal.', 0),
        }


        Db::getInstance()->Execute("CREATE TABLE IF NOT EXISTS " . _DB_PREFIX_ . "smspubli_admin_sms_config (
            `id` INT(3) NOT NULL AUTO_INCREMENT,
            `hook` VARCHAR(100) CHARACTER SET utf8 NOT NULL,
            `option_id` TINYINT(1),
            `message` LONGTEXT CHARACTER SET utf8 NOT NULL,
            PRIMARY KEY (`id`)
            ) ENGINE=InnoDB  DEFAULT CHARSET=utf8;");

        if (! Db::getInstance()->ExecuteS("SELECT * FROM ". _DB_PREFIX_ . "smspubli_admin_sms_config")) {
            Db::getInstance()->Execute("INSERT INTO " . _DB_PREFIX_ . "smspubli_admin_sms_config
                (`id`, `hook`, `option_id`, `message`) VALUES
                (2, 'actionOrderStatusPostUpdate', 2, 'El estado del pedido {order_id} ha cambiado a pago  aceptado.'),
                (3, 'actionOrderStatusPostUpdate', 3, 'El estado del pedido {order_id} ha cambiado a preparación en proceso.'),
                (4, 'actionOrderStatusPostUpdate', 4, 'El pedido {order_id} ha sido enviado.'),
                (5, 'actionOrderStatusPostUpdate', 5, 'El estado del pedido {order_id} ha cambiado a entregado.'),
                (6, 'actionOrderStatusPostUpdate', 6, 'El estado del pedido {order_id} ha cambiado a cancelado.'),
                (7, 'actionOrderStatusPostUpdate', 7, 'El estado del pedido {order_id} ha cambiado a reembolso.'),
                (8, 'actionOrderStatusPostUpdate', 8, 'El estado del pedido {order_id} ha cambiado a error en el pago.'),
                (9, 'actionOrderStatusPostUpdate', 9, 'El estado del pedido {order_id} ha cambiado a productos fuera de línea.'),
                (12, 'actionOrderStatusPostUpdate', 12, 'El estado del pedido {order_id} ha cambiado a pago a distancia aceptado.'),
                (13, 'actionValidateOrder', 0, 'Nuevo pedido con id {order_id} del cliente {customer_id}. Modo de pago: {order_payment}. Importe: {order_total_paid}{order_currency}'),
                (14, 'actionPaymentConfirmation', 0, 'Se ha confirmado el pago del pedido {order_id}. Modo de pago: {order_payment}. Importe: {order_total_paid}{order_currency}'),
                (15, 'actionOrderReturn', 0, 'El cliente {customer_id} ha solicitado la devolución de productos del pedido {order_id}. Motivo del cliente: {customer_question}.'),
                (16, 'actionProductOutOfStock', 0, 'El producto {product_name} está fuera de stock. Ref: {product_ref}. Cantidad: {product_quantity}.'),
                (17, 'actionProductDelete', 0, 'El producto {product_name} con id: {product_id} y ref: {product_ref} ha sido eliminado por el usuario {employee_id} con email {employee_email}.'),
                (18, 'actionUpdateQuantity', 0, 'La cantidad del producto {product_name} con id: {product_id} y ref: {product_ref} ha cambiado. Cantidad actual: {product_quantity}.'),
                (19, 'actionCustomerAccountAdd', 0, 'Se ha creado una nueva cuenta en {shop_name}. Cliente: {customer_firstname} {customer_lastname}. Email: {customer_email}. Id: {customer_id}.')");

                //(1, 'actionOrderStatusPostUpdate', 1, 'El estado del pedido {order_id} ha cambiado a pendiente de pago por cheque.'),
                //(10, 'actionOrderStatusPostUpdate', 10, 'El estado del pedido {order_id} ha cambiado a pendiente de pago por transferencia bancaria.'),
                //(11, 'actionOrderStatusPostUpdate', 11, 'El estado del pedido {order_id} ha cambiado a pendiente de pago por PayPal.'),
        }

        Db::getInstance()->Execute("CREATE TABLE IF NOT EXISTS " . _DB_PREFIX_ . "smspubli_admin_sms_config_active (
            `id_sms` INT(3) NOT NULL DEFAULT '0',
            `id_admin` INT(3) NOT NULL DEFAULT '0',
            `active` TINYINT(1) NOT NULL DEFAULT '0',
            PRIMARY KEY (`id_sms`, `id_admin`)
            ) ENGINE=InnoDB  DEFAULT CHARSET=utf8;");

        Db::getInstance()->Execute("CREATE TABLE IF NOT EXISTS " . _DB_PREFIX_ . "smspubli_out_of_stock_notifications (
            `id_product` VARCHAR(30) NOT NULL,
            `sended` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id_product`)
            ) ENGINE=InnoDB  DEFAULT CHARSET=utf8;");


        $this->registerHook('displayBackOfficeHeader');

        //Order Status
        $this->registerHook('actionOrderStatusPostUpdate');
        //Order
        $this->registerHook('actionValidateOrder');
        $this->registerHook('actionPaymentConfirmation');
        $this->registerHook('actionOrderReturn');
        //Account
        $this->registerHook('actionCustomerAccountAdd');
        //Product
        $this->registerHook('actionProductOutOfStock');
        $this->registerHook('actionProductDelete');
        //$this->registerHook('actionUpdateQuantity');

        $this->createTab("SMSpubli", "SMSpubli", 0);

        $idParent = Tab::getIdFromClassName("SMSpubli");

        $this->createTab("Home", $this->l('Home'), $idParent);
        $this->createTab("SmsNotifications", $this->l('SMS notifications'), $idParent);
        $this->createTab("SmsCampaigns", $this->l('SMS campaigns'), $idParent);
        $this->createTab("Settings", $this->l('Settings'), $idParent);
        $this->createTab("AddBalance", $this->l('Add balance'), $idParent);

        return true;
    }

    public function uninstall()
    {
        if(parent::uninstall() == false)
        {
            return false;
        }

        Db::getInstance()->Execute("DROP TABLE IF EXISTS " . _DB_PREFIX_ . "smspubli_module_config");
        Db::getInstance()->Execute("DROP TABLE IF EXISTS " . _DB_PREFIX_ . "smspubli_prefix");
        Db::getInstance()->Execute("DROP TABLE IF EXISTS " . _DB_PREFIX_ . "smspubli_admins");
        Db::getInstance()->Execute("DROP TABLE IF EXISTS " . _DB_PREFIX_ . "smspubli_customer_sms_config");
        Db::getInstance()->Execute("DROP TABLE IF EXISTS " . _DB_PREFIX_ . "smspubli_admin_sms_config");
        Db::getInstance()->Execute("DROP TABLE IF EXISTS " . _DB_PREFIX_ . "smspubli_admin_sms_config_active");
        Db::getInstance()->Execute("DROP TABLE IF EXISTS " . _DB_PREFIX_ . "smspubli_sms_pending");
        Db::getInstance()->Execute("DROP TABLE IF EXISTS " . _DB_PREFIX_ . "smspubli_sms_sent");
        Db::getInstance()->Execute("DROP TABLE IF EXISTS " . _DB_PREFIX_ . "smspubli_sms_dlr");
        Db::getInstance()->Execute("DROP TABLE IF EXISTS " . _DB_PREFIX_ . "smspubli_out_of_stock_notifications");


        $this->deleteTab('SMSpubli');
        $this->deleteTab('Home');
        $this->deleteTab('SmsNotifications');
        $this->deleteTab('SmsCampaigns');
        $this->deleteTab('Settings');
        $this->deleteTab('AddBalance');
    }

    public function hookDisplayBackOfficeHeader()
    {
        if(isset($this->context->controller))
        {
            $this->context->controller->addCSS(($this->_path)."css/page.css", "all");
            $this->context->controller->addCSS("https://netdna.bootstrapcdn.com/font-awesome/4.0.3/css/font-awesome.css", "all");
			$this->context->smarty->assign(array(
                'print_links' => false,
            ));
        }
		else{
            $this->context->smarty->assign(array(
                'print_links' => true,
            ));
        }
    }

    /******** Hooks response *********/

    //Order Status

    public function hookActionOrderStatusPostUpdate($params)
    {
        $controller_hook = HookActionController::getInstance();

        if($controller_hook->isActivedHook('actionOrderStatusPostUpdate', $params['newOrderStatus']->id))
            $controller_hook->actionOrderStatusPostUpdate($params);
    }

    //Order

    public function hookActionValidateOrder($params)
    {
        $controller_hook = HookActionController::getInstance();

        if($controller_hook->isActivedHook('actionValidateOrder'))
            $controller_hook->actionValidateOrder($params);
    }

    public function hookActionPaymentConfirmation($params)
    {
        $controller_hook = HookActionController::getInstance();

        if($controller_hook->isActivedHook('actionPaymentConfirmation'))
            $controller_hook->actionPaymentConfirmation($params);
    }

    public function hookActionOrderReturn($params)
    {
        $controller_hook = HookActionController::getInstance();

        if($controller_hook->isActivedHook('actionOrderReturn'))
            $controller_hook->actionOrderReturn($params);
    }


    //Account

    public function hookActionCustomerAccountAdd($params)
    {
        $controller_hook = HookActionController::getInstance();

        if($controller_hook->isActivedHook('actionCustomerAccountAdd'))
            $controller_hook->actionCustomerAccountAdd($params);

    }

    //Product

    public function hookActionProductOutOfStock($params)
    {
        $controller_hook = HookActionController::getInstance();

        if($controller_hook->isActivedHook('actionProductOutOfStock'))
            $controller_hook->actionProductOutOfStock($params);
    }

    public function hookActionProductDelete($params)
    {
        $controller_hook = HookActionController::getInstance();

        if($controller_hook->isActivedHook('actionProductDelete'))
            $controller_hook->actionProductDelete($params);
    }

    /*public function hookActionUpdateQuantity($params)
    {
        $controller_hook = HookActionController::getInstance();

        if($controller_hook->isActivedHook('actionUpdateQuantity') && $params['id_product_attribute']==0)
            $controller_hook->actionUpdateQuantity($params);
    }*/

    /******** End hooks response *********/


    public function createTab($tabClass, $tabName, $idParent)
    {
        $tab = new Tab();
        foreach(Language::getLanguages(false) as $lang){
            $tab->name[(int) $lang['id_lang']] = $tabName;
        }
        $tab->class_name = $tabClass;
        $tab->module = $this->name;
        $tab->id_parent = $idParent;

        if (!$tab->save()) {
            return false;
        }
        return true;

    }

    public function deleteTab($tabClass)
    {
        $idTab = Tab::getIdFromClassName($tabClass);
        if($idTab != 0)
        {
            $tab = new Tab($idTab);
            $tab->delete();
            return true;
        }
        return false;
    }

    private function insertPrefixes(){
        Db::getInstance()->Execute("INSERT INTO " . _DB_PREFIX_ . "smspubli_prefix
        (`id`, `iso_alpha2`, `calling_code`, `mcc`, `name_es`, `name_en`, `name_it`, `name_de`, `name_fr`, `name_pt`) VALUES
        (1, 'AD', '376', '213', 'Andorra', 'Andorra', 'Andorra', 'Andorra', 'Andorre', 'Andorra'),
        (2, 'AE', '971', '424', 'Emiratos Árabes Unidos', 'United Arab Emirates', 'Emirati Arabi Uniti', 'Vereinigte Arabische Emirate', 'Émirats Arabes Unis', 'Emirados Árabes Unidos'),
        (3, 'AF', '93', '412', 'Afganistán', 'Afghanistan', 'Afghanistan', 'Afghanistan', 'Afghanistan', 'Afeganistão'),
        (4, 'AG', '1268', '344', 'Antigua y Barbuda', 'Antigua and Barbuda', 'Antigua e Barbuda', 'Antigua und Barbuda', 'Antigua et Barbuda', 'Antígua e Barbuda'),
        (5, 'AI', '1264', '365', 'Anguila', 'Anguilla', 'Anguilla', 'Anguilla', 'Anguilla', 'Anguila'),
        (6, 'AL', '355', '276', 'Albania', 'Albania', 'Albania', 'Albanien', 'Albanie', 'Albânia'),
        (7, 'AM', '374', '283', 'Armenia', 'Armenia', 'Armenia', 'Armenien', 'Arménie', 'Armênia'),
        (8, 'AO', '244', '631', 'Angola', 'Angola', 'Angola', 'Angola', 'Angola', 'Angola'),
        (9, 'AR', '54', '722', 'Argentina', 'Argentina', 'Argentina', 'Argentinien', 'Argentine', 'Argentina'),
        (10, 'AS', '1684', '544', 'Samoa Americana', 'American Samoa', 'Samoa Americane', 'Amerikanisch-Samoa', 'Samoa américaines', 'Samoa Americana'),
        (11, 'AT', '43', '232', 'Austria', 'Austria', 'Austria', 'Österreich', 'Autriche', 'Áustria'),
        (12, 'AU', '61', '505', 'Australia', 'Australia', 'Australia', 'Australien', 'Australie', 'Austrália'),
        (13, 'AW', '297', '363', 'Aruba', 'Aruba', 'Aruba', 'Aruba', 'Aruba', 'Aruba'),
        (14, 'AZ', '994', '400', 'Azerbaiyán', 'Azerbaijan', 'Azerbaigian', 'Aserbaidschan', 'Azerbaïdjan', 'Azerbaijão'),
        (15, 'BA', '387', '218', 'Bosnia y Herzegovina', 'Bosnia and Herzegovina', 'Bosnia-Erzegovina', 'Bosnien und Herzegowina', 'Bosnie-Herzégovine', 'Bósnia-Herzegovina'),
        (16, 'BB', '1246', '342', 'Barbados', 'Barbados', 'Barbados', 'Barbados', 'Barbade (La)', 'Barbados'),
        (17, 'BD', '880', '470', 'Bangladesh', 'Bangladesh', 'Bangladesh', 'Bangladesch', 'Bangladesh', 'Bangladesh'),
        (18, 'BE', '32', '206', 'Bélgica', 'Belgium', 'Belgio', 'Belgien', 'Belgique', 'Bélgica'),
        (19, 'BF', '226', '613', 'Burkina Faso', 'Burkina Faso', 'Burkina Faso', 'Burkina Faso', 'Burkina Faso', 'Burkina Fasso'),
        (20, 'BG', '359', '284', 'Bulgaria', 'Bulgaria', 'Bulgaria', 'Bulgarien', 'Bulgarie', 'Bulgária'),
        (21, 'BH', '973', '426', 'Bahréin', 'Bahrain', 'Bahrein', 'Bahrain', 'Bahreïn', 'Barein'),
        (22, 'BI', '257', '642', 'Burundi', 'Burundi', 'Burundi', 'Burundi', 'Burundi', 'Burundi'),
        (23, 'BJ', '229', '616', 'Benín', 'Benin', 'Benin', 'Benin', 'Bénin', 'Benin'),
        (24, 'BM', '1441', '350', 'Bermudas', 'Bermuda', 'Bermuda', 'Bermudas', 'Bermudes', 'Bermudas'),
        (25, 'BN', '673', '528', 'Brunéi', 'Brunei', 'Brunei', 'Brunei', 'Brunei', 'Brunei'),
        (26, 'BO', '591', '736', 'Bolivia', 'Bolivia', 'Bolivia', 'Bolivien', 'Bolivie', 'Bolívia'),
        (27, 'BR', '55', '724', 'Brasil', 'Brazil', 'Brasile', 'Brasilien', 'Brésil', 'Brasil'),
        (28, 'BS', '1242', '364', 'Bahamas', 'Bahamas', 'Bahamas', 'Bahamas', 'Bahamas', 'Bahamas'),
        (29, 'BT', '975', '402', 'Bután', 'Bhutan', 'Bhutan', 'Bhutan', 'Bhutan', 'Butão'),
        (30, 'BW', '267', '652', 'Botsuana', 'Botswana', 'Botswana', 'Botsuana', 'Botswana', 'Botsuana'),
        (31, 'BY', '375', '257', 'Bielorrusia', 'Belarus', 'Bielorussia', 'Weißrussland', 'Biélorussie', 'Bielo-Rússia'),
        (32, 'BZ', '501', '702', 'Belice', 'Belize', 'Belize', 'Belize', 'Belize', 'Belize'),
        (33, 'CA', '1', '302', 'Canadá', 'Canada', 'Canada', 'Kanada', 'Canada', 'Canadá'),
        (34, 'CD', '243', '630', 'República Democrática del Congo', 'Congo - Democratic Republic of', 'Congo, Repubblica Democratica del', 'Kongo - Demokratische Republik', 'Congo (République démocratique du)', 'República Democrática do Congo'),
        (35, 'CF', '236', '623', 'República Centroafricana', 'Central African Republic', 'Repubblica Centrafricana', 'Zentralafrikanische Republik', 'République Centrafricaine', 'República Centro-Africana'),
        (36, 'CG', '242', '629', 'Congo', 'Congo', 'Congo', 'Kongo', 'Congo', 'Congo'),
        (37, 'CH', '41', '228', 'Suiza', 'Switzerland', 'Svizzera', 'Schweiz', 'Suisse', 'Suíça'),
        (38, 'CK', '682', '548', 'Islas Cook', 'Cook Islands', 'Cook, isole', 'Cook-Inseln', 'Cook (Îles)', 'Ilhas Cook'),
        (39, 'CL', '56', '730', 'Chile', 'Chile', 'Cile', 'Chile', 'Chili', 'Chile'),
        (40, 'CM', '237', '624', 'Camerún', 'Cameroon', 'Camerun', 'Kamerun', 'Cameroun', 'Camarões'),
        (41, 'CN', '86', '460', 'China', 'China', 'Cina', 'China', 'Chine', 'China'),
        (42, 'CO', '57', '732', 'Colombia', 'Colombia', 'Colombia', 'Kolumbien', 'Colombie', 'Colômbia'),
        (43, 'CR', '506', '712', 'Costa Rica', 'Costa Rica', 'Costa Rica', 'Costa Rica', 'Costa Rica', 'Costa Rica'),
        (44, 'CU', '53', '368', 'Cuba', 'Cuba', 'Cuba', 'Kuba', 'Cuba', 'Cuba'),
        (45, 'CV', '238', '625', 'Cabo Verde', 'Cape Verde', 'Capo Verde', 'Kap Verde', 'Cap-Vert', 'Cabo Verde'),
        (46, 'CY', '357', '280', 'Chipre', 'Cyprus', 'Cipro', 'Zypern', 'Chypre', 'Chipre'),
        (47, 'CZ', '420', '230', 'República Checa', 'Czech Republic', 'Repubblica Ceca', 'Tschechien', 'République tchèque', 'República Tcheca'),
        (48, 'DE', '49', '262', 'Alemania', 'Germany', 'Germania', 'Deutschland', 'Allemagne', 'Alemanha'),
        (49, 'DJ', '253', '638', 'Yibuti', 'Djibouti', 'Gibuti', 'Dschibuti', 'Djibouti', 'Djibuti'),
        (50, 'DK', '45', '238', 'Dinamarca', 'Denmark', 'Danimarca', 'Dänemark', 'Danemark', 'Dinamarca'),
        (51, 'DM', '1767', '366', 'Dominica', 'Dominica', 'Dominica', 'Dominica', 'Dominique', 'Dominica'),
        (52, 'DO', '1809', '370', 'República Dominicana', 'Dominican Republic', 'Repubblica Dominicana', 'Dominikanische Republik', 'République Dominicaine', 'República Dominicana'),
        (53, 'DO', '1829', '371', 'República Dominicana', 'Dominican Republic', 'Repubblica Dominicana', 'Dominikanische Republik', 'République Dominicaine', 'República Dominicana'),
        (54, 'DO', '1849', '373', 'República Dominicana', 'Dominican Republic', 'Repubblica Dominicana', 'Dominikanische Republik', 'République Dominicaine', 'República Dominicana'),
        (55, 'DZ', '213', '603', 'Argelia', 'Algeria', 'Algeria', 'Algerien', 'Algérie', 'Argélia'),
        (56, 'EC', '593', '740', 'Ecuador', 'Ecuador', 'Ecuador', 'Ecuador', 'Équateur', 'Equador'),
        (57, 'EE', '372', '248', 'Estonia', 'Estonia', 'Estonia', 'Estland', 'Estonie', 'Estónia'),
        (58, 'EG', '20', '602', 'Egipto', 'Egypt', 'Egitto', 'Ägypten', 'Égypte', 'Egito'),
        (59, 'ES', '34', '214', 'España (Península)', 'Spain', 'Spagna', 'Spanien', 'Espagne', 'Espanha'),
        (60, 'ET', '251', '636', 'Etiopía', 'Ethiopia', 'Etiopia', 'Äthiopien', 'Éthiopie', 'Etiópia'),
        (61, 'FI', '358', '244', 'Finlandia', 'Finland', 'Finlandia', 'Finnland', 'Finlande', 'Finlândia'),
        (62, 'FJ', '679', '542', 'Fiyi', 'Fiji', 'Figi', 'Fidschi', 'Fidji', 'Fiji'),
        (63, 'FK', '500', '750', 'Islas Malvinas', 'Falkland Islands (Islas Malvinas)', 'Isole Falkland (Isole Malvine)', 'Falklandinseln (Malvinas)', 'Malouines (Îles)', 'Ilhas Falkland (Malvinas)'),
        (64, 'FO', '298', '288', 'Islas Feroe', 'Faroe Islands', 'Faroe, isole', 'Färöer-Inseln', 'Faroe (Îles)', 'Ilhas Faroé'),
        (65, 'FR', '33', '208', 'Francia', 'France', 'Francia', 'Frankreich', 'France', 'França'),
        (66, 'GA', '241', '628', 'Gabón', 'Gabon', 'Gabon', 'Gabun', 'Gabon', 'Gabão'),
        (67, 'GB', '44', '234', 'Reino Unido', 'United Kingdom', 'Regno Unito', 'Großbritannien und Nordirland', 'Royaume-Uni', 'Reino Unido'),
        (68, 'GD', '1473', '352', 'Granada', 'Grenada', 'Grenada', 'Grenada', 'Grenade', 'Granada'),
        (69, 'GE', '995', '282', 'Georgia', 'Georgia', 'Georgia', 'Georgien', 'Georgia', 'Georgia'),
        (70, 'GF', '594', '742', 'Guayana francesa', 'French Guyana', 'Guiana francese', 'Französisch-Guyana', 'Guyane française', 'Guiana Francesa'),
        (71, 'GH', '233', '620', 'Ghana', 'Ghana', 'Ghana', 'Ghana', 'Ghana', 'Gana'),
        (72, 'GI', '350', '266', 'Gibraltar', 'Gibraltar', 'Gibilterra', 'Gibraltar', 'Gibraltar', 'Gibraltar'),
        (73, 'GL', '299', '290', 'Groenlandia', 'Greenland', 'Groenlandia', 'Grönland', 'Groenland', 'Groenlândia'),
        (74, 'GM', '220', '607', 'Gambia', 'Gambia', 'Gambia', 'Gambia', 'Gambie', 'Gâmbia'),
        (75, 'GN', '224', '611', 'Guinea', 'Guinea', 'Guinea', 'Guinea', 'Guinée', 'Guiné'),
        (76, 'GQ', '240', '627', 'Guinea Ecuatorial', 'Equitorial Guinea', 'Guinea Equatoriale', 'Äquatorialguinea', 'Guinée équatoriale', 'Guiné Equatorial'),
        (77, 'GR', '30', '202', 'Grecia', 'Greece', 'Grecia', 'Griechenland', 'Grèce', 'Grécia'),
        (78, 'GT', '502', '704', 'Guatemala', 'Guatemala', 'Guatemala', 'Guatemala', 'Guatemala', 'Guatemala'),
        (79, 'GW', '245', '632', 'Guinea-Bissau', 'Guinea-Bissau', 'Guinea-Bissau', 'Guinea-Bissau', 'Guinée-Bissau', 'Guiné-Bissau'),
        (80, 'GY', '592', '738', 'Guyana', 'Guyana', 'Guiana', 'Guyana', 'Guyane', 'Guiana'),
        (81, 'HK', '852', '454', 'Hong Kong', 'Hong Kong', 'Hong Kong', 'Hongkong', 'Hong Kong', 'Hong Kong'),
        (82, 'HN', '504', '708', 'Honduras', 'Honduras', 'Honduras', 'Honduras', 'Honduras', 'Honduras'),
        (83, 'HR', '385', '219', 'Croacia', 'Croatia', 'Croazia', 'Kroatien', 'Croatie', 'Croácia'),
        (84, 'HT', '509', '372', 'Haití', 'Haiti', 'Haiti', 'Haiti', 'Haïti', 'Haiti'),
        (85, 'HU', '36', '216', 'Hungría', 'Hungary', 'Ungheria', 'Ungarn', 'Hongrie', 'Hungria'),
        (86, 'ID', '62', '510', 'Indonesia', 'Indonesia', 'Indonesia', 'Indonesien', 'Indonésie', 'Indonésia'),
        (87, 'IE', '353', '272', 'Irlanda', 'Ireland', 'Irlanda', 'Irland', 'Irlande', 'Irlanda'),
        (88, 'IN', '91', '405', 'La India', 'India', 'India', 'Indien', 'Inde', 'Índia'),
        (89, 'IQ', '964', '418', 'Iraq', 'Iraq', 'Iraq', 'Irak', 'Irak', 'Iraque'),
        (90, 'IR', '98', '432', 'Irán', 'Iran', 'Iran', 'Iran', 'Iran', 'Irão'),
        (91, 'IS', '354', '274', 'Islandia', 'Iceland', 'Islanda', 'Island', 'Islande', 'Islândia'),
        (92, 'IT', '39', '222', 'Italia', 'Italy', 'Italia', 'Italien', 'Italie', 'Itália'),
        (93, 'JM', '1876', '338', 'Jamaica', 'Jamaica', 'Giamaica', 'Jamaika', 'Jamaïque', 'Jamaica'),
        (94, 'JO', '962', '416', 'Jordania', 'Jordan', 'Giordania', 'Jordanien', 'Jordanie', 'Jordânia'),
        (95, 'JP', '81', '441', 'Japón', 'Japan', 'Giappone', 'Japan', 'Japon', 'Japão'),
        (96, 'KE', '254', '639', 'Kenia', 'Kenya', 'Kenya', 'Kenia', 'Kenya', 'Quênia'),
        (97, 'KG', '996', '437', 'Kirguistán', 'Kyrgyzstan', 'Kirghizistan', 'Kirgistan', 'Kirghizistan', 'Quirguistão'),
        (98, 'KH', '855', '456', 'Camboya', 'Cambodia', 'Cambogia', 'Kambodscha', 'Cambodge', 'Camboja'),
        (99, 'KM', '269', '654', 'Comoras', 'Comoros', 'Comore', 'Komoren', 'Comores (Archipel)', 'Ilhas Comores'),
        (100, 'KN', '1869', '356', 'San Cristóbal y Nieves', 'Saint Kitts and Nevis', 'Saint Kitts e Nevis', 'Saint Kitts und Nevis', 'Saint-Kitts-et-Nevis', 'São Cristóvão e Névis'),
        (101, 'KR', '82', '450', 'Corea del Sur', 'South Korea', 'Corea del Sud', 'Südkorea', 'Corée du Sud', 'Coreia do Sul'),
        (102, 'KW', '965', '419', 'Kuwait', 'Kuwait', 'Kuwait', 'Kuwait', 'Koweït', 'Kuwait'),
        (103, 'KY', '1345', '346', 'Islas Caimán', 'Cayman Islands', 'Cayman, isole', 'Cayman-Inseln', 'Caïmans (Îles)', 'Ilhas Cayman'),
        (104, 'KZ', '7', '401', 'Kazajstán', 'Kazakhstan', 'Kazakistan', 'Kasachstan', 'Kazakhstan', 'Cazaquistão'),
        (105, 'LA', '856', '457', 'Laos', 'Laos', 'Laos', 'Laos', 'Laos', 'Laos'),
        (106, 'LB', '961', '415', 'El Líbano', 'Lebanon', 'Libano', 'Libanon', 'Liban', 'Líbano'),
        (107, 'LC', '1758', '358', 'Santa Lucía', 'Saint Lucia', 'Santa Lucia', 'St. Lucia', 'Sainte-Lucie', 'Santa Lúcia'),
        (108, 'LI', '423', '295', 'Liechtenstein', 'Liechtenstein', 'Liechtenstein', 'Liechtenstein', 'Liechtenstein', 'Liechtenstein'),
        (109, 'LK', '94', '413', 'Sri Lanka', 'Sri Lanka', 'Sri Lanka', 'Sri Lanka', 'Sri Lanka', 'Sri Lanka'),
        (110, 'LR', '231', '618', 'Liberia', 'Liberia', 'Liberia', 'Liberia', 'Liberia', 'Libéria'),
        (111, 'LS', '266', '651', 'Lesoto', 'Lesotho', 'Lesotho', 'Lesotho', 'Lesotho', 'Lesoto'),
        (112, 'LT', '370', '246', 'Lituania', 'Lithuania', 'Lituania', 'Litauen', 'Lituanie', 'Lituânia'),
        (113, 'LU', '352', '270', 'Luxemburgo', 'Luxembourg', 'Lussemburgo', 'Luxemburg', 'Luxembourg', 'Luxemburgo'),
        (114, 'LV', '371', '247', 'Letonia', 'Latvia', 'Lettonia', 'Lettland', 'Lettonie', 'Letônia'),
        (115, 'LY', '218', '606', 'Libia', 'Libya', 'Libia', 'Libyen', 'Libye', 'Líbia'),
        (116, 'MA', '212', '604', 'Marruecos', 'Morocco', 'Marocco', 'Marokko', 'Maroc', 'Marrocos'),
        (117, 'MC', '377', '212', 'Mónaco', 'Monaco', 'Monaco', 'Monaco', 'Monaco', 'Mônaco'),
        (118, 'MD', '373', '259', 'Moldavia', 'Moldova', 'Moldavia', 'Republik Moldau', 'Moldavie', 'Moldávia'),
        (119, 'MG', '261', '646', 'Madagascar', 'Madagascar', 'Madagascar', 'Madagaskar', 'Madagascar', 'Madagascar'),
        (120, 'ML', '223', '610', 'Mali', 'Mali', 'Mali', 'Mali', 'Mali', 'Mali'),
        (121, 'MN', '976', '428', 'Mongolia', 'Mongolia', 'Mongolia', 'Mongolei', 'Mongolie', 'Mongólia'),
        (122, 'MO', '853', '455', 'Macao', 'Macau', 'Macao', 'Macao', 'Macao', 'Macau'),
        (123, 'MQ', '596', '340', 'Martinica', 'Martinique', 'Martinica', 'Martinique', 'Martinique', 'Martinica'),
        (124, 'MR', '222', '609', 'Mauritania', 'Mauritania', 'Mauritania', 'Mauretanien', 'Mauritanie', 'Mauritânia'),
        (125, 'MS', '1664', '354', 'Montserrat', 'Montserrat', 'Montserrat', 'Montserrat', 'Montserrat', 'Montserrat'),
        (126, 'MT', '356', '278', 'Malta', 'Malta', 'Malta', 'Malta', 'Malte', 'Malta'),
        (127, 'MU', '230', '617', 'Mauricio', 'Mauritius', 'Mauritius', 'Mauritius', 'Maurice (Île)', 'Ilhas Maurício'),
        (128, 'MV', '960', '472', 'Maldivas', 'Maldives', 'Maldive', 'Malediven', 'Maldives', 'Maldivas'),
        (129, 'MW', '265', '650', 'Malaui', 'Malawi', 'Malawi', 'Malawi', 'Malawi', 'Malauí'),
        (130, 'MX', '52', '334', 'México', 'Mexico', 'Messico', 'Mexiko', 'Mexique', 'México'),
        (131, 'MY', '60', '502', 'Malasia', 'Malaysia', 'Malesia', 'Malaysia', 'Malaisie', 'Malásia'),
        (132, 'MZ', '258', '643', 'Mozambique', 'Mozambique', 'Mozambico', 'Mosambik', 'Mozambique', 'Moçambique'),
        (133, 'NA', '264', '649', 'Namibia', 'Namibia', 'Namibia', 'Namibia', 'Namibie', 'Namíbia'),
        (134, 'NC', '687', '546', 'Nueva Caledonia', 'New Caledonia', 'Nuova Caledonia', 'Neukaledonien', 'Nouvelle-Calédonie', 'Nova Caledônia'),
        (135, 'NE', '227', '614', 'Níger', 'Niger', 'Niger', 'Niger', 'Niger', 'Níger'),
        (136, 'NG', '234', '621', 'Nigeria', 'Nigeria', 'Nigeria', 'Nigeria', 'Nigéria', 'Nigéria'),
        (137, 'NI', '505', '710', 'Nicaragua', 'Nicaragua', 'Nicaragua', 'Nicaragua', 'Nicaragua', 'Nicarágua'),
        (138, 'NL', '31', '204', 'Países Bajos', 'Netherlands', 'Paesi Bassi', 'Niederlande', 'Pays-Bas', 'Holanda'),
        (139, 'NO', '47', '242', 'Noruega', 'Norway', 'Norvegia', 'Norwegen', 'Norvège', 'Noruega'),
        (140, 'NP', '977', '429', 'Nepal', 'Nepal', 'Nepal', 'Nepal', 'Népal', 'Nepal'),
        (141, 'NZ', '64', '530', 'Nueva Zelanda', 'New Zealand', 'Nuova Zelanda', 'Neuseeland', 'Nouvelle-Zélande', 'Nova Zelândia'),
        (142, 'OM', '968', '422', 'Omán', 'Oman', 'Oman', 'Oman', 'Oman', 'Oman'),
        (143, 'PA', '507', '714', 'Panamá', 'Panama', 'Panama', 'Panama', 'Panama', 'Panamá'),
        (144, 'PE', '51', '716', 'Perú', 'Peru', 'Perù', 'Peru', 'Pérou', 'Peru'),
        (145, 'PF', '689', '547', 'Polinesia Francesa', 'French Polynesia', 'Polinesia Francese', 'Französisch-Polynesien', 'Polynésie française', 'Polinésia Francesa'),
        (146, 'PG', '675', '537', 'Papúa-Nueva Guinea', 'Papua New Guinea', 'Papua Nuova Guinea', 'Papua-Neuguinea', 'Papouasie-Nouvelle Guinée', 'Papua-Nova Guiné'),
        (147, 'PH', '63', '515', 'Filipinas', 'Philippines', 'Filippine', 'Philippinen', 'Philippines', 'Filipinas'),
        (148, 'PK', '92', '410', 'Pakistán', 'Pakistan', 'Pakistan', 'Pakistan', 'Pakistan', 'Paquistão'),
        (149, 'PL', '48', '260', 'Polonia', 'Poland', 'Polonia', 'Polen', 'Pologne', 'Polónia'),
        (150, 'PR', '1787', '330', 'Puerto Rico', 'Puerto Rico', 'Portorico', 'Puerto Rico', 'Porto Rico', 'Porto Rico'),
        (151, 'PR', '1939', '', 'Puerto Rico', 'Puerto Rico', 'Portorico', 'Puerto Rico', 'Porto Rico', 'Porto Rico'),
        (152, 'PS', '972', '425', 'Cisjordania', 'West Bank', 'Cisgiordania', 'Westjordanland', 'Cisjordanie', 'Cisjordânia'),
        (153, 'PT', '351', '268', 'Portugal', 'Portugal', 'Portogallo', 'Portugal', 'Portugal', 'Portugal'),
        (154, 'PW', '680', '552', 'Palaos', 'Palau', 'Palau', 'Palau', 'Palau', 'Palau'),
        (155, 'PY', '595', '744', 'Paraguay', 'Paraguay', 'Paraguay', 'Paraguay', 'Paraguay', 'Paraguai'),
        (156, 'QA', '974', '427', 'Qatar', 'Qatar', 'Qatar', 'Katar', 'Qatar', 'Catar'),
        (157, 'RE', '262', '647', 'Reunión', 'Reunion', 'Riunione, isola di', 'Réunion', 'Réunion (Île de la)', 'Ilha Reunião'),
        (158, 'RO', '40', '226', 'Rumanía', 'Romania', 'Romania', 'Rumänien', 'Roumanie', 'Roménia'),
        (159, 'RU', '7', '250', 'Rusia', 'Russia', 'Russia', 'Russland', 'Russie', 'Rússia'),
        (160, 'RW', '250', '635', 'Ruanda', 'Rwanda', 'Ruanda', 'Ruanda', 'Rwanda', 'Ruanda'),
        (161, 'SA', '966', '420', 'Arabia Saudí', 'Saudi Arabia', 'Arabia Saudita', 'Saudi-Arabien', 'Arabie Saoudite', 'Arábia Saudita'),
        (162, 'SB', '677', '540', 'Islas Salomón', 'Solomon Islands', 'Salomone, isole', 'Solomon-Inseln', 'Solomon (Îles)', 'Ilhas Salomão'),
        (163, 'SC', '248', '633', 'Seychelles', 'Seychelles', 'Seychelles', 'Seychellen', 'Seychelles', 'Ilhas Seychelles'),
        (164, 'SD', '249', '634', 'Sudán', 'Sudan', 'Sudan', 'Sudan', 'Soudan', 'Sudão'),
        (165, 'SE', '46', '240', 'Suecia', 'Sweden', 'Svezia', 'Schweden', 'Suède', 'Suécia'),
        (166, 'SG', '65', '525', 'Singapur', 'Singapore', 'Singapore', 'Singapur', 'Singapour', 'Singapura'),
        (167, 'SI', '386', '293', 'Eslovenia', 'Slovenia', 'Slovenia', 'Slowenien', 'Slovénie', 'Eslovénia'),
        (168, 'SK', '421', '231', 'Eslovaquia', 'Slovakia', 'Slovacchia', 'Slowakei', 'Slovaquie', 'Eslováquia'),
        (169, 'SL', '232', '619', 'Sierra Leona', 'Sierra Leone', 'Sierra Leone', 'Sierra Leone', 'Sierra Leone', 'Serra Leoa'),
        (170, 'SN', '221', '608', 'Senegal', 'Senegal', 'Senegal', 'Senegal', 'Sénégal', 'Senegal'),
        (171, 'SO', '252', '637', 'Somalia', 'Somalia', 'Somalia', 'Somalia', 'Somalie', 'Somália'),
        (172, 'SR', '597', '746', 'Surinam', 'Suriname', 'Suriname', 'Suriname', 'Surinam', 'Suriname'),
        (173, 'ST', '239', '626', 'Santo Tomé y Príncipe', 'Sao Tome and Principe', 'Sao Tomè e Principe', 'São Tomé und Príncipe', 'São Tomé et Príncipe', 'São Tomé e Príncipe'),
        (174, 'SV', '503', '706', 'El Salvador', 'El Salvador', 'El Salvador', 'El Salvador', 'Salvador', 'El Salvador'),
        (175, 'SY', '963', '417', 'Siria', 'Syria', 'Siria', 'Syrien', 'Syrie', 'Síria'),
        (176, 'SZ', '268', '653', 'Suazilandia', 'Swaziland', 'Swaziland', 'Swasiland', 'Swaziland', 'Suazilândia'),
        (177, 'TC', '1649', '376', 'Islas Turcas y Caicos', 'Turks and Caicos Islands', 'Turks e Caicos', 'Turks- und Caicos-Inseln', 'Turks et Caïcos (Îles)', 'Ilhas Turks e Caicos'),
        (178, 'TD', '235', '622', 'Chad', 'Chad', 'Ciad', 'Tschad', 'Tchad', 'Chade'),
        (179, 'TG', '228', '615', 'Togo', 'Togo', 'Togo', 'Togo', 'Togo', 'Togo'),
        (180, 'TH', '66', '520', 'Tailandia', 'Thailand', 'Tailandia', 'Thailand', 'Thaïlande', 'Tailândia'),
        (181, 'TJ', '992', '436', 'Tayikistán', 'Tajikistan', 'Tagikistan', 'Tadschikistan', 'Tadjikistan', 'Tajiquistão'),
        (182, 'TL', '640', '514', 'Timor Oriental', 'Timor-Leste', 'Timor Leste', 'Timor-Leste', 'Timor-Leste', 'Timor-Leste'),
        (183, 'TM', '993', '438', 'Turkmenistán', 'Turkmenistan', 'Turkmenistan', 'Turkmenistan', 'Turkménistan', 'Turcomenistão'),
        (184, 'TN', '216', '605', 'Túnez', 'Tunisia', 'Tunisia', 'Tunesien', 'Tunisie', 'Tunísia'),
        (185, 'TO', '676', '539', 'Tonga', 'Tonga', 'Tonga', 'Tonga', 'Tonga', 'Tonga'),
        (186, 'TR', '90', '286', 'Turquía', 'Turkey', 'Turchia', 'Türkei', 'Turquie', 'Turquia'),
        (187, 'TT', '1868', '374', 'Trinidad y Tobago', 'Trinidad and Tobago', 'Trinidad e Tobago', 'Trinidad und Tobago', 'Trinidad et Tobago', 'Trinidad e Tobago'),
        (188, 'TW', '886', '466', 'Taiwán', 'Taiwan', 'Taiwan', 'Taiwan', 'Taïwan', 'Taiwan'),
        (189, 'TZ', '255', '640', 'Tanzania', 'Tanzania', 'Tanzania', 'Tansania', 'Tanzanie', 'Tanzânia'),
        (190, 'UA', '380', '255', 'Ucrania', 'Ukraine', 'Ucraina', 'Ukraine', 'Ukraine', 'Ucrânia'),
        (191, 'UG', '256', '641', 'Uganda', 'Uganda', 'Uganda', 'Uganda', 'Ouganda', 'Uganda'),
        (192, 'US', '1', '310', 'Estados Unidos', 'United States', 'Stati Uniti', 'USA', 'États-Unis', 'Estados Unidos'),
        (193, 'UY', '598', '748', 'Uruguay', 'Uruguay', 'Uruguay', 'Uruguay', 'Uruguay', 'Uruguai'),
        (194, 'UZ', '998', '434', 'Uzbekistán', 'Uzbekistan', 'Uzbekistan', 'Usbekistan', 'Ouzbékistan', 'Uzbequistão'),
        (195, 'VC', '1784', '360', 'San Vicente y las Granadinas', 'Saint Vincent and the Grenadines', 'Saint Vincent e Grenadine', 'St. Vincent und die Grenadinen', 'Saint-Vincent et les Grenadines', 'São Vincente e Granadinas'),
        (196, 'VE', '58', '734', 'Venezuela', 'Venezuela', 'Venezuela', 'Venezuela', 'Venezuela', 'Venezuela'),
        (197, 'VG', '1284', '348', 'Islas Vírgenes Británicas', 'British Virgin Islands', 'Isole Vergini britanniche', 'Britische Jungferninseln', 'Îles Vierges britanniques', 'Ilhas Virgens (Grã Bretanha)'),
        (198, 'VN', '84', '452', 'Vietnam', 'Vietnam', 'Vietnam', 'Vietnam', 'Vietnam', 'Vietname'),
        (199, 'VU', '678', '541', 'Vanuatu', 'Vanuatu', 'Vanuatu', 'Vanuatu', 'Vanuatu', 'Vanuatu'),
        (200, 'WS', '685', '549', 'Samoa', 'Samoa', 'Samoa', 'Samoa', 'Samoa', 'Samoa'),
        (201, 'YE', '967', '421', 'Yemen', 'Yemen', 'Yemen', 'Jemen', 'Yémen', 'Iémen'),
        (202, 'ZA', '27', '655', 'Sudáfrica', 'South Africa', 'Sudafrica', 'Südafrika', 'Afrique du Sud', 'África do Sul'),
        (203, 'ZM', '260', '645', 'Zambia', 'Zambia', 'Zambia', 'Sambia', 'Zambie', 'Zâmbia'),
        (204, 'ZW', '263', '648', 'Zimbabue', 'Zimbabwe', 'Zimbabwe', 'Simbabwe', 'Zimbabwe', 'Zimbábue')");
    }
}

?>

